==> core-components-file-upload-item-5.6.7.tgz: package/modern/Component.js <==
import React from 'react';
import cn from 'classnames';
import { IconButton } from '@alfalab/core-components-icon-button/modern';
import { Link } from '@alfalab/core-components-link/modern';
import { Spinner } from '@alfalab/core-components-spinner/modern';
import { AlertCircleMIcon } from '@alfalab/icons-glyph/AlertCircleMIcon';
import { CheckmarkCircleMIcon } from '@alfalab/icons-glyph/CheckmarkCircleMIcon';
import { ClockMIcon } from '@alfalab/icons-glyph/ClockMIcon';
import { CrossSIcon } from '@alfalab/icons-glyph/CrossSIcon';
import { PointerDownSIcon } from '@alfalab/icons-glyph/PointerDownSIcon';
import { humanFileSize, fileIcon } from './utils.js';

const styles = {"component":"file-upload-item__component_wec4u","infoSection":"file-upload-item__infoSection_wec4u","info":"file-upload-item__info_wec4u","icon":"file-upload-item__icon_wec4u","errorIcon":"file-upload-item__errorIcon_wec4u","successIcon":"file-upload-item__successIcon_wec4u","name":"file-upload-item__name_wec4u","rowLimit":"file-upload-item__rowLimit_wec4u","meta":"file-upload-item__meta_wec4u","size":"file-upload-item__size_wec4u","delete":"file-upload-item__delete_wec4u","download":"file-upload-item__download_wec4u","errorWrapper":"file-upload-item__errorWrapper_wec4u","restore":"file-upload-item__restore_wec4u","spinnerWrapper":"file-upload-item__spinnerWrapper_wec4u","spinner":"file-upload-item__spinner_wec4u","uploadPercent":"file-upload-item__uploadPercent_wec4u"};
require('./index.css')

const FileUploadItem = ({ className, children, id = '0', name = '', size, icon: Icon = fileIcon(name), uploadDate, downloadLink, download, uploadStatus, uploadPercent = 0, error, showDelete, showRestore, onDelete, onDownload, onRestore, disableButtons, multiline = false, dataTestId, }) => {
    const handleDownload = (event) => {
        if (onDownload) {
            event.preventDefault();
            onDownload(id);
        }
    };
    const handleDelete = (event) => {
        if (onDelete)
            onDelete(id, event);
    };
    const handleRestore = () => {
        if (onRestore)
            onRestore(id);
    };
    const renderIcon = () => {
        if (showRestore) {
            return React.createElement(ClockMIcon, { className: styles.restoreIcon });
        }
        switch (uploadStatus) {
            case 'ERROR':
                return React.createElement(AlertCircleMIcon, { className: styles.errorIcon });
            case 'SUCCESS':
                return React.createElement(CheckmarkCircleMIcon, { className: styles.successIcon });
            case 'LOADING':
            case 'UPLOADING':
                return (React.createElement("div", { className: styles.spinnerWrapper },
                    React.createElement(Spinner, { visible: true, className: styles.spinner })));
            default: {
                return React.createElement(Icon, { className: styles.icon });
            }
        }
    };
    const renderInfoSection = () => {
        const shouldShownError = uploadStatus === 'ERROR' || !!error;
        const errorContent = uploadStatus === 'ERROR' && !error ? 'Не удалось загрузить файл' : error;
        return (React.createElement("div", { className: styles.infoSection },
            React.createElement("div", { className: cn(styles.name, { [styles.rowLimit]: !multiline }) }, name),
            shouldShownError && (React.createElement("div", { className: styles.errorWrapper, role: 'alert' }, errorContent))));
    };
    const showMeta = !showRestore && (!uploadStatus || uploadStatus === 'SUCCESS');
    const showDownload = Boolean(downloadLink) && !showRestore;
    return (React.createElement("div", { className: cn(className, styles.component, uploadStatus && styles[uploadStatus.toLocaleLowerCase()]), "data-test-id": dataTestId },
        React.createElement("div", { className: styles.info },
            renderIcon(),
            renderInfoSection(),
            children,
            uploadStatus === 'UPLOADING' && (React.createElement("span", { className: styles.uploadPercent }, `${Math.round(uploadPercent)}%`)),
            showMeta && (React.createElement("div", { className: styles.meta },
                uploadDate && React.createElement("span", { key: uploadDate }, uploadDate),
                size && (React.createElement("span", { key: size, className: styles.size }, humanFileSize(size)))))),
        showRestore && (React.createElement(Link, { pseudo: true, className: styles.restore, onClick: handleRestore }, "\u0412\u043E\u0441\u0441\u0442\u0430\u043D\u043E\u0432\u0438\u0442\u044C")),
        showDownload && (React.createElement(IconButton, { size: 'xxs', icon: PointerDownSIcon, className: styles.download, "aria-label": '\u0441\u043A\u0430\u0447\u0430\u0442\u044C', href: downloadLink, onClick: handleDownload, disabled: disableButtons, download: download })),
        showDelete && !showRestore && (React.createElement(IconButton, { size: 'xxs', icon: CrossSIcon, onClick: handleDelete, disabled: disableButtons, className: styles.delete, "aria-label": '\u0443\u0434\u0430\u043B\u0438\u0442\u044C' }))));
};

export { FileUploadItem };

==> core-components-file-upload-item-5.6.8.tgz: package/modern/Component.js <==
import React from 'react';
import cn from 'classnames';
import { IconButton } from '@alfalab/core-components-icon-button/modern';
import { Link } from '@alfalab/core-components-link/modern';
import { Spinner } from '@alfalab/core-components-spinner/modern';
import { AlertCircleMIcon } from '@alfalab/icons-glyph/AlertCircleMIcon';
import { CheckmarkCircleMIcon } from '@alfalab/icons-glyph/CheckmarkCircleMIcon';
import { ClockMIcon } from '@alfalab/icons-glyph/ClockMIcon';
import { CrossSIcon } from '@alfalab/icons-glyph/CrossSIcon';
import { PointerDownSIcon } from '@alfalab/icons-glyph/PointerDownSIcon';
import { humanFileSize, fileIcon } from './utils.js';

const styles = {"component":"file-upload-item__component_sr4cm","infoSection":"file-upload-item__infoSection_sr4cm","info":"file-upload-item__info_sr4cm","icon":"file-upload-item__icon_sr4cm","errorIcon":"file-upload-item__errorIcon_sr4cm","successIcon":"file-upload-item__successIcon_sr4cm","name":"file-upload-item__name_sr4cm","rowLimit":"file-upload-item__rowLimit_sr4cm","meta":"file-upload-item__meta_sr4cm","size":"file-upload-item__size_sr4cm","delete":"file-upload-item__delete_sr4cm","download":"file-upload-item__download_sr4cm","errorWrapper":"file-upload-item__errorWrapper_sr4cm","restore":"file-upload-item__restore_sr4cm","spinnerWrapper":"file-upload-item__spinnerWrapper_sr4cm","spinner":"file-upload-item__spinner_sr4cm","uploadPercent":"file-upload-item__uploadPercent_sr4cm"};
require('./index.css')

const FileUploadItem = ({ className, children, id = '0', name = '', size, icon: Icon = fileIcon(name), uploadDate, downloadLink, download, uploadStatus, uploadPercent = 0, error, showDelete, showRestore, onDelete, onDownload, onRestore, disableButtons, multiline = false, dataTestId, }) => {
    const handleDownload = (event) => {
        if (onDownload) {
            event.preventDefault();
            onDownload(id);
        }
    };
    const handleDelete = (event) => {
        if (onDelete)
            onDelete(id, event);
    };
    const handleRestore = () => {
        if (onRestore)
            onRestore(id);
    };
    const renderIcon = () => {
        if (showRestore) {
            return React.createElement(ClockMIcon, { className: styles.restoreIcon });
        }
        switch (uploadStatus) {
            case 'ERROR':
                return React.createElement(AlertCircleMIcon, { className: styles.errorIcon });
            case 'SUCCESS':
                return React.createElement(CheckmarkCircleMIcon, { className: styles.successIcon });
            case 'LOADING':
            case 'UPLOADING':
                return (React.createElement("div", { className: styles.spinnerWrapper },
                    React.createElement(Spinner, { visible: true, className: styles.spinner })));
            default: {
                return React.createElement(Icon, { className: styles.icon });
            }
        }
    };
    const renderInfoSection = () => {
        const shouldShownError = uploadStatus === 'ERROR' || !!error;
        const errorContent = uploadStatus === 'ERROR' && !error ? 'Не удалось загрузить файл' : error;
        return (React.createElement("div", { className: styles.infoSection },
            React.createElement("div", { className: cn(styles.name, { [styles.rowLimit]: !multiline }) }, name),
            shouldShownError && (React.createElement("div", { className: styles.errorWrapper, role: 'alert' }, errorContent))));
    };
    const showMeta = !showRestore && (!uploadStatus || uploadStatus === 'SUCCESS');
    const showDownload = Boolean(downloadLink) && !showRestore;
    return (React.createElement("div", { className: cn(className, styles.component, uploadStatus && styles[uploadStatus.toLocaleLowerCase()]), "data-test-id": dataTestId },
        React.createElement("div", { className: styles.info },
            renderIcon(),
            renderInfoSection(),
            children,
            uploadStatus === 'UPLOADING' && (React.createElement("span", { className: styles.uploadPercent }, `${Math.round(uploadPercent)}%`)),
            showMeta && (React.createElement("div", { className: styles.meta },
                uploadDate && React.createElement("span", { key: uploadDate }, uploadDate),
                size && (React.createElement("span", { key: size, className: styles.size }, humanFileSize(size)))))),
        showRestore && (React.createElement(Link, { pseudo: true, className: styles.restore, onClick: handleRestore }, "\u0412\u043E\u0441\u0441\u0442\u0430\u043D\u043E\u0432\u0438\u0442\u044C")),
        showDownload && (React.createElement(IconButton, { size: 'xxs', icon: PointerDownSIcon, className: styles.download, "aria-label": '\u0441\u043A\u0430\u0447\u0430\u0442\u044C', href: downloadLink, onClick: handleDownload, disabled: disableButtons, download: download })),
        showDelete && !showRestore && (React.createElement(IconButton, { size: 'xxs', icon: CrossSIcon, onClick: handleDelete, disabled: disableButtons, className: styles.delete, "aria-label": '\u0443\u0434\u0430\u043B\u0438\u0442\u044C' }))));
};

export { FileUploadItem };
